@@ -15,7 +15,7 @@ deploy::build-docs
 # build the sdist and save the dirs before the clean
 python setup.py sdist
 mv dist dist_saved
-mv .venv .venv_saved
+mv .venv /tmp/.venv
 
 # for the tarball upload
 # clean up
@@ -23,7 +23,7 @@ git clean -Xdf
 
 # restore the saved "dist"/".venv" directory
 mv dist_saved dist
-mv .venv_saved .venv
+mv /tmp/.venv .venv
 
 # make the dir
 rm -rf ./tag_build || true
@@ -57,7 +57,8 @@ with tarfile.open("tag_build/${PKG_NAME_VER}.tar", mode="a:") as tf:
     tf.add("README.rst", arcname="${PKG_NAME_VER}/README.rst")
 EOF
 
-gzip ./tag_build/${PKG_NAME_VER}.tar
-
-sha512sum --binary ./tag_build/${PKG_NAME_VER}.tar.gz > ./tag_build/${PKG_NAME_VER}.sha512sum
+pushd ./tag_build
+gzip ${PKG_NAME_VER}.tar
 
+sha512sum --binary ${PKG_NAME_VER}.tar.gz > ${PKG_NAME_VER}.sha512sum
+popd
