@@ -26,6 +26,12 @@ if [ x"$FLAKE" = "xyes" ]; then
     fi
 fi
 
+python -m mypy .
+MYPY_RES=$?
+if [ $MYPY_RES -ne 0 ]; then
+    exit $MYPY_RES
+fi
+
 # always build in-place so that Sphinx can find the modules
 python setup.py build_ext --inplace $EXTRA_BUILDEXT
 BUILD_RES=$?
@@ -40,5 +46,5 @@ if [ "$OS_NAME" = "windows" ]; then
     # Windows can't run the tests yet, so just make sure it imports and exit
     python -c "import gssapi" || exit $?
 else
-    python setup.py nosetests --verbosity=3 || exit $?
+    python -m unittest -v || exit $?
 fi
